==> jc-1.4.0.tar.gz: java/awt/FontFormatException.h <==
// public class java.awt.FontFormatException

// class file dependencies
// @dep_class 17e0732bb423405e java_awt_FontFormatException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_FontFormatException_H_
#define _JC_java_awt_FontFormatException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_FontFormatException$sub_refs	_jc_java_awt_FontFormatException$sub_refs;
typedef struct _jc_java_awt_FontFormatException$sub_nonrefs	_jc_java_awt_FontFormatException$sub_nonrefs;
typedef struct _jc_java_awt_FontFormatException$refs	_jc_java_awt_FontFormatException$refs;
typedef struct _jc_java_awt_FontFormatException$nonrefs	_jc_java_awt_FontFormatException$nonrefs;
typedef struct _jc_java_awt_FontFormatException$object	_jc_java_awt_FontFormatException$object;

typedef struct _jc_java_awt_FontFormatException$fields_struct	_jc_java_awt_FontFormatException$fields_struct;
typedef const struct _jc_java_awt_FontFormatException$vmethods	_jc_java_awt_FontFormatException$vmethods;
typedef const struct _jc_java_awt_FontFormatException$vtable	_jc_java_awt_FontFormatException$vtable;
typedef const struct _jc_java_awt_FontFormatException$vtype	_jc_java_awt_FontFormatException$vtype;

// Class fields structure
struct _jc_java_awt_FontFormatException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_FontFormatException$fields_struct _jc_java_awt_FontFormatException$class_fields;

// Constructors
extern void _jc_java_awt_FontFormatException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_FontFormatException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_FontFormatException$vmethods {
};

// Vtable
struct _jc_java_awt_FontFormatException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_FontFormatException$vmethods	java_awt_FontFormatException;
};

// Vtype
struct _jc_java_awt_FontFormatException$vtype {
	_jc_type			type;
	_jc_java_awt_FontFormatException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_FontFormatException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_FontFormatException$refs {
    _jc_java_awt_FontFormatException$sub_refs	java_awt_FontFormatException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_FontFormatException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_FontFormatException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_FontFormatException$sub_nonrefs	java_awt_FontFormatException;
};

// Object instance structure
struct _jc_java_awt_FontFormatException$object {
	_jc_java_awt_FontFormatException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_FontFormatException$vtype	*vtype;
	_jc_java_awt_FontFormatException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_FontFormatException$vtype _jc_java_awt_FontFormatException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_FontFormatException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_FontFormatException$class_object;

#endif	/* _JC_java_awt_FontFormatException_H_ */

==> jc-1.4.6.tar.gz: java/awt/FontFormatException.h <==
// public class java.awt.FontFormatException

// class file dependencies
// @dep_class 17e0732bb423405e java_awt_FontFormatException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_FontFormatException_H_
#define _JC_java_awt_FontFormatException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_FontFormatException$sub_refs	_jc_java_awt_FontFormatException$sub_refs;
typedef struct _jc_java_awt_FontFormatException$sub_nonrefs	_jc_java_awt_FontFormatException$sub_nonrefs;
typedef struct _jc_java_awt_FontFormatException$refs	_jc_java_awt_FontFormatException$refs;
typedef struct _jc_java_awt_FontFormatException$nonrefs	_jc_java_awt_FontFormatException$nonrefs;
typedef struct _jc_java_awt_FontFormatException$object	_jc_java_awt_FontFormatException$object;

typedef struct _jc_java_awt_FontFormatException$fields_struct	_jc_java_awt_FontFormatException$fields_struct;
typedef const struct _jc_java_awt_FontFormatException$vmethods	_jc_java_awt_FontFormatException$vmethods;
typedef const struct _jc_java_awt_FontFormatException$vtable	_jc_java_awt_FontFormatException$vtable;
typedef const struct _jc_java_awt_FontFormatException$vtype	_jc_java_awt_FontFormatException$vtype;

// Class fields structure
struct _jc_java_awt_FontFormatException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_FontFormatException$fields_struct _jc_java_awt_FontFormatException$class_fields;

// Constructors
extern void _jc_java_awt_FontFormatException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_FontFormatException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_FontFormatException$vmethods {
};

// Vtable
struct _jc_java_awt_FontFormatException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_FontFormatException$vmethods	java_awt_FontFormatException;
};

// Vtype
struct _jc_java_awt_FontFormatException$vtype {
	_jc_type			type;
	_jc_java_awt_FontFormatException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_FontFormatException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_FontFormatException$refs {
    _jc_java_awt_FontFormatException$sub_refs	java_awt_FontFormatException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_FontFormatException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_FontFormatException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_FontFormatException$sub_nonrefs	java_awt_FontFormatException;
};

// Object instance structure
struct _jc_java_awt_FontFormatException$object {
	_jc_java_awt_FontFormatException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_FontFormatException$vtype	*vtype;
	_jc_java_awt_FontFormatException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_FontFormatException$vtype _jc_java_awt_FontFormatException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_FontFormatException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_FontFormatException$class_object;

#endif	/* _JC_java_awt_FontFormatException_H_ */
